function c2curve = splineCurve(interpPoints, nbPoints)
% c2curve = splineCurve(interPoints) returns a C2boundary curve 
% that passes throught all interpolated points.
% interPoints is of size 2 * N with N >= nbPoints

N=size(interpPoints,2); %number of interpolated points

% loop points for spline interpolation
if interpPoints(:,N) ~= interpPoints(:,1)
    interpPoints(:,N+1)=interpPoints(:,1);
    N = N+1;
end

if nargin < 2
    nbPoints = N-1;
end

if nbPoints < N-1
    error('The number of points on the boundary must be greater than the number of interpolated points')
end

% sum of the sqrt of distances between points
% see documentation of cscvn
period_parameter = sum([((diff(interpPoints').^2)*ones(2,1)).^(1/4)]);
t = linspace(0,period_parameter,nbPoints+1);
t = t(1:nbPoints);

%spline between points. curve is a function
curve = cscvn(interpPoints);

points = fnval(curve,t);
tvec = fnval(fnder(curve), t);
avec = fnval(fnder(curve,2), t);

%take parametrization between [0, 2\pi]
scale = period_parameter/2/pi;
tvec = tvec*scale;
avec = avec*scale^2;

c2curve = C2boundary(points, tvec, avec);
end
